django-pgstats
########################################################################

Documentation
=============

`View the django-pgstats docs here
<https://django-pgstats.readthedocs.io/>`_.

Installation
============

Install django-pgstats with::

    pip3 install django-pgstats

After this, add ``pgstats`` to the ``INSTALLED_APPS``
setting of your Django project.

Contributing Guide
==================

For information on setting up django-pgstats for development and
contributing changes, view `CONTRIBUTING.rst <CONTRIBUTING.rst>`_.

Primary Authors
===============

- @wesleykendall (Wes Kendall)
- @tomage (Tómas Árni Jónasson)
